==> calamares_3.2.20.orig.tar.gz: calamares-3.2.20/src/modules/plasmalnf/PlasmaLnfViewStep.h <==
/* === This file is part of Calamares - <https://github.com/calamares> ===
 *
 *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
 *
 *   Calamares is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Calamares is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef PLASMALNFVIEWSTEP_H
#define PLASMALNFVIEWSTEP_H

#include <utils/PluginFactory.h>
#include <viewpages/ViewStep.h>
#include <DllMacro.h>

#include <QObject>
#include <QUrl>
#include <QVariantMap>

class PlasmaLnfPage;

class PLUGINDLLEXPORT PlasmaLnfViewStep : public Calamares::ViewStep
{
    Q_OBJECT

public:
    explicit PlasmaLnfViewStep( QObject* parent = nullptr );
    virtual ~PlasmaLnfViewStep() override;

    QString prettyName() const override;

    QWidget* widget() override;

    bool isNextEnabled() const override;
    bool isBackEnabled() const override;

    bool isAtBeginning() const override;
    bool isAtEnd() const override;

    void onLeave() override;

    Calamares::JobList jobs() const override;

    void setConfigurationMap( const QVariantMap& configurationMap ) override;

public slots:
    void themeSelected( const QString& id );

private:
    PlasmaLnfPage* m_widget;
    QString m_lnfPath;  // Path to the lnf tool
    QString m_themeId;  // Id of selected theme
    QString m_liveUser; // Name of the live user (for OEM mode)
};

CALAMARES_PLUGIN_FACTORY_DECLARATION( PlasmaLnfViewStepFactory )

#endif // PLASMALNFVIEWSTEP_H

==> calamares_3.2.24.orig.tar.gz: calamares-3.2.24/src/modules/plasmalnf/PlasmaLnfViewStep.h <==
/* === This file is part of Calamares - <https://github.com/calamares> ===
 *
 *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
 *
 *   Calamares is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Calamares is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef PLASMALNFVIEWSTEP_H
#define PLASMALNFVIEWSTEP_H

#include "utils/PluginFactory.h"
#include "viewpages/ViewStep.h"
#include "DllMacro.h"

#include <QObject>
#include <QUrl>
#include <QVariantMap>

class PlasmaLnfPage;

class PLUGINDLLEXPORT PlasmaLnfViewStep : public Calamares::ViewStep
{
    Q_OBJECT

public:
    explicit PlasmaLnfViewStep( QObject* parent = nullptr );
    virtual ~PlasmaLnfViewStep() override;

    QString prettyName() const override;

    QWidget* widget() override;

    bool isNextEnabled() const override;
    bool isBackEnabled() const override;

    bool isAtBeginning() const override;
    bool isAtEnd() const override;

    void onLeave() override;

    Calamares::JobList jobs() const override;

    void setConfigurationMap( const QVariantMap& configurationMap ) override;

public slots:
    void themeSelected( const QString& id );

private:
    PlasmaLnfPage* m_widget;
    QString m_lnfPath;  // Path to the lnf tool
    QString m_themeId;  // Id of selected theme
    QString m_liveUser; // Name of the live user (for OEM mode)
};

CALAMARES_PLUGIN_FACTORY_DECLARATION( PlasmaLnfViewStepFactory )

#endif // PLASMALNFVIEWSTEP_H
